#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-asn1-types
version:              0.4.1
visibility:           public
id:                   crypton-asn1-types-0.4.1-BiQ5G0i0Z0nKQl6axuGGOt
key:                  crypton-asn1-types-0.4.1-BiQ5G0i0Z0nKQl6axuGGOt
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    Mike Pilgrem <public@pilgrem.com>,
    Kazu Yamamoto <kazu@iij.ad.jp>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/mpilgrem/crypton-asn1
synopsis:             ASN.1 types
description:
    A library providing types representing the Abstract Syntax Notation One
    (ASN.1) standard.

category:             Data
abi:                  4687b5b23ff9719686188b498063f458
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Stream
    Data.ASN1.Types Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-asn1-types-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-asn1-types-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-asn1-types-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-asn1-types
hs-libraries:         HScrypton-asn1-types-0.4.1-BiQ5G0i0Z0nKQl6axuGGOt
depends:
    base-4.18.2.1 base16-1.0-GDZ0UO2PCml3zNf7S0mskP bytestring-0.11.5.3
    time-hourglass-0.3.0-6rRx9lp97jZ8aUmo5Iq8q

haddock-interfaces:
    /usr/share/doc/haskell-crypton-asn1-types/html/crypton-asn1-types.haddock

haddock-html:         /usr/share/doc/haskell-crypton-asn1-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

